function normy = nflips2
% Plots the probability of x% of Z coin tosses coming up heads
% Uses one array of Z for discrete calculations (discz) and
% one for only a continuous approximation (zgam)
% Jason Kahn U Maryland 4/20/2016  version 1.01
% Some plots are scaled to max probability ("normalized")
% Probability(H) = (Z!)/[(H!)(T!)]
% ln(P) = ln(Z!) - ln(H!) - ln((Z-H)!)
% The gamma function generalizes the factorial Gamma(X) = (X-1)!
% Could rewrite to take these arrays as arguments...
discz = [ 3 5 8 20 100 ]; % The max is 170, as factorial(171) = Inf
zgam = [discz 200 500 1000 5000 100000 500000];
incr = 0.2;  % increment for smooth curves
% Should not need to change below
x = incr:incr:100-incr;
y = zeros(length(x),length(zgam));
y2 = y;
normy = y;
absy2 = y;
normy3 = y;
discx = cell(1,length(discz));
discy = cell(1,length(discz));
for i = 1:length(discz)   %  we are calculating factorials directly
    z = discz(i);
    discx{1,i}(1,:) = zeros(1,2*(z+1));
    discy{1,i}(1,:) = zeros(1,2*(z+1));
    facts = factorial(z)./(factorial(0:z).*factorial(z:-1:0));
    discx{1,i}(1,1:2) = [0 100/(z+1)];
    discy{1,i}(1,1:2) = [1 1]*(z+1)/(2^z);
    for j = 1:z
        discx{1,i}(1,2*j+1:2*j+2) = [j*100/(z+1) (j+1)*100/(z+1)];
        discy{1,i}(1,2*j+1:2*j+2) = [facts(j+1) facts(j+1)]*(z+1)/(2^z);
    end
    %area = (100)*sum(facts)/2^z
end
hc = figure;
axes('FontSize',14);
hold on
box on
for j = 1:length(discz)
    plot(discx{1,j},discy{1,j},'LineWidth',1.5)
    legstr{j} = [num2str(discz(j)), ' flips'] ;
end
title('Coin Flip Statistics')
xlabel('% Heads')
ylabel('Probability')
set(gca,'XTick',[0:10:100])
legend(legstr,'FontSize',14)

for i = 1:length(zgam)
    z = zgam(i);
    y(:,i) = gammaln(z+1)-gammaln(x*z/100 + 1)-gammaln((100-x)*z/100 + 1);
    y(:,i) = y(:,i)-max(y(:,i));
    normy(:,i) = exp(y(:,i));
    % Uncomment for absolute probability
    absy2(:,i) = normy(:,i)/sum(normy(:,i));
    legstr2{i} = [num2str(zgam(i)), ' flips'] ;
end
set(gca,'ColorOrderIndex',1)
plot(x,(100/incr)*absy2(:,1:length(discz)),'LineWidth',1.0)
% Zoom in
x2 = 45+incr/10:incr/10:55-incr/10;
for i = 1:length(zgam)
    z = zgam(i);
    y2(:,i) = gammaln(z+1)-gammaln(x2*z/100 + 1)-gammaln((100-x2)*z/100 + 1);
    y2(:,i) = y2(:,i)-max(y2(:,i));
    normy3(:,i) = exp(y2(:,i));
end
figure
h = axes('FontSize',14);
plot(x,normy,'LineWidth',1.5);
title('Coin Flip Statistics')
xlabel('% Heads')
ylabel('Normalized Probability')
set(gca,'XTick',[0:10:100])
legend(legstr2,'FontSize',14)
figure
h = axes('FontSize',14,'FontWeight','demi'); % Bold doesn't work with default font?
plot(x,absy2,'LineWidth',1.5);
title('Coin Flip Statistics')
xlabel('% Heads')
ylabel('Probability')
set(gca,'XTick',[0:10:100])
legend(legstr2,'FontSize',14)
figure
h = axes('FontSize',14);
plot(x2,normy3,'LineWidth',1.5);
title('Coin Flip Statistics')
xlabel('% Heads')
ylabel('Normalized Probability')
set(gca,'XTick',[45:55])
legend(legstr2,'FontSize',14)







